From: Pedro Alves <palves@redhat.com>
To: gdb-patches@sourceware.org
Subject: [COMMIT PATCH 1/2] savestring: Rename parameter 'size' to 'len'.
Date: Thu, 14 Feb 2013 17:14:00 -0000 [thread overview]
Message-ID: <20130214171404.2223.83713.stgit@brno.lan> (raw)
It's better to avoid needless confusion, and call a string's length,
length, instead of size, which is usually used to refer to sizeof of
the string (len+1):
size_t len = strlen (str);
size_t size = sizeof (str);
Tested on x86_64 Fedora 17.
2013-02-14 Pedro Alves <palves@redhat.com>
* utils.c (savestring): Rename parameter 'size' to 'len'.
---
gdb/utils.c | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/gdb/utils.c b/gdb/utils.c
index 282ab8b..408c6ce 100644
--- a/gdb/utils.c
+++ b/gdb/utils.c
@@ -1186,17 +1186,17 @@ myread (int desc, char *addr, int len)
return orglen;
}
/* Make a copy of the string at PTR with SIZE characters
(and add a null character at the end in the copy).
Uses malloc to get the space. Returns the address of the copy. */
char *
-savestring (const char *ptr, size_t size)
+savestring (const char *ptr, size_t len)
{
- char *p = (char *) xmalloc (size + 1);
+ char *p = (char *) xmalloc (len + 1);
- memcpy (p, ptr, size);
- p[size] = 0;
+ memcpy (p, ptr, len);
+ p[len] = 0;
return p;
}
next reply other threads:[~2013-02-14 17:14 UTC|newest]
Thread overview: 13+ messages / expand[flat|nested] mbox.gz Atom feed top
2013-02-14 17:14 Pedro Alves [this message]
2013-02-14 17:14 ` [COMMIT PATCH 2/2] Move savestring to common/common-utils.c, make gdbserver use it Pedro Alves
2013-02-14 18:07 ` Tom Tromey
2013-02-14 18:08 ` Pedro Alves
2013-02-14 18:10 ` Tom Tromey
2013-02-14 18:14 ` Pedro Alves
2013-02-14 18:24 ` Tom Tromey
2013-02-14 18:31 ` Pedro Alves
2013-02-14 18:54 ` Joel Brobecker
2013-02-14 20:35 ` Tom Tromey
2013-02-14 21:05 ` Joel Brobecker
2013-02-21 21:15 ` Tom Tromey
2013-02-14 18:30 ` [COMMIT PATCH 1/2] savestring: Rename parameter 'size' to 'len' Mark Kettenis
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20130214171404.2223.83713.stgit@brno.lan \
--to=palves@redhat.com \
--cc=gdb-patches@sourceware.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1186,17 +1186,17 @@ myread (int desc, char *addr, int len)
return orglen;
}
-/* Make a copy of the string at PTR with SIZE characters
+/* Make a copy of the string at PTR with LEN characters
(and add a null character at the end in the copy).
Uses malloc to get the space. Returns the address of the copy. */
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox